@@ -1,5 +1,5 @@
 package XML::Grammar::FictionBase::TagsTree2XML;
-$XML::Grammar::FictionBase::TagsTree2XML::VERSION = '0.26.3';
+$XML::Grammar::FictionBase::TagsTree2XML::VERSION = '0.28.0';
 use strict;
 use warnings;
 
@@ -233,18 +233,28 @@ sub _write_elem_childs
 
         die "elem=[$elem]";
     }
+    my $kids;
     if ( ref($elem) eq 'ARRAY' )
     {
-        # body...
-        foreach my $child (@$elem)
-        {
-            $self->_write_elem( { elem => $child, }, );
-        }
-        return;
+        $kids = $elem;
     }
-    foreach my $child ( @{ $elem->_get_childs() } )
+    else
     {
+        $kids = $elem->_get_childs();
+    }
+    my $prev_child;
+    foreach my $child ( @{$kids} )
+    {
+        if ( defined $prev_child )
+        {
+            if ( $prev_child->_short_isa("InnerDesc")
+                and ( ref($child) and !$child->_short_isa("Text") ) )
+            {
+                $self->_write_elem( { elem => ' ', }, );
+            }
+        }
         $self->_write_elem( { elem => $child, }, );
+        $prev_child = $child;
     }
 
     return;
@@ -494,7 +504,7 @@ Internal - (to settle pod-coverage.).
 
 =head1 VERSION
 
-version 0.26.3
+version 0.28.0
 
 =for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
