@@ -1,5 +1,5 @@
 package XML::Grammar::Screenplay::FromProto;
-$XML::Grammar::Screenplay::FromProto::VERSION = '0.26.3';
+$XML::Grammar::Screenplay::FromProto::VERSION = '0.28.0';
 use strict;
 use warnings;
 use autodie;
@@ -181,6 +181,20 @@ sub _handle_elem_of_name_section
     return $self->_handle_elem_of_name_s($elem);
 }
 
+sub _handle_elem_of_name_strong
+{
+    my ( $self, $elem ) = @_;
+
+    $self->_output_tag_with_childs(
+        {
+            start => [ "strong", ],
+            elem  => $elem,
+        }
+    );
+
+    return;
+}
+
 sub _bold_tag_name
 {
     return "bold";
@@ -274,7 +288,7 @@ Converts the file $path_to_file to XML and returns it.
 
 =head1 VERSION
 
-version 0.26.3
+version 0.28.0
 
 =for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
